@@ -140,51 +140,69 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         // line 59
         yield "            </script>
             <script>
-                document.addEventListener('DOMContentLoaded', function () {
+                (function () {
+                    // prevent double-install (avoids breaking pages)
+                    if (window.__causeBuzzTitlePatchInstalled) return;
+                    window.__causeBuzzTitlePatchInstalled = true;
 
                     const BRAND = 'Cause Buzz';
 
-                    function updateTitleSafe() {
+                    function normalizeTitle() {
+                        try {
+                            let t = (document.title || '').trim();
 
-                        // Delay ensures Mautic finished updating title
-                        setTimeout(function () {
+                            // remove trailing \"| Mautic\"
+                            t = t.replace(/\\s*\\|\\s*Mautic\\s*\$/i, '').trim();
 
-                            var current = document.title || '';
-
-                            // Remove \"Mautic\"
-                            current = current.replace(/\\|\\s*Mautic\$/i, '').trim();
-
-                            // Remove duplicate brand
-                            current = current.replace(new RegExp('\\\\|\\\\s*' + BRAND + '\$', 'i'), '').trim();
-
-                            // If empty
-                            if (!current || current === 'Mautic') {
+                            // if title is empty or exactly \"Mautic\", just use the brand
+                            if (!t || /^Mautic\$/i.test(t)) {
                                 document.title = BRAND;
                                 return;
                             }
 
-                            document.title = current + ' | ' + BRAND;
+                            // avoid \"Cause Buzz | Cause Buzz\"
+                            if (new RegExp('^' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\\\\|\\\\s*' + BRAND + '\$', 'i').test(t)) {
+                                document.title = BRAND;
+                                return;
+                            }
 
-                        }, 0);
+                            // avoid double appends
+                            if (new RegExp('\\\\|\\\\s*' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\$', 'i').test(t)) {
+                                document.title = t;
+                                return;
+                            }
+
+                            document.title = t + ' | ' + BRAND;
+                        } catch (e) {
+                            // swallow errors so we never break the UI
+                        }
                     }
 
-                    // Initial load
-                    updateTitleSafe();
+                    function scheduleNormalize() {
+                        // run after Mautic has finished its SPA title update
+                        setTimeout(normalizeTitle, 0);
+                    }
 
-                    // Safe Mautic SPA hook
-                    document.addEventListener('mautic:page:load', updateTitleSafe);
+                    // first load
+                    if (document.readyState === 'loading') {
+                        document.addEventListener('DOMContentLoaded', scheduleNormalize, { once: true });
+                    } else {
+                        scheduleNormalize();
+                    }
 
-                });
+                    // SPA navigation hook
+                    document.addEventListener('mautic:page:load', scheduleNormalize);
+                })();
             </script>
 
             ";
-        // line 98
+        // line 116
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 99
+        // line 117
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 102
+        // line 120
         yield "
         </section>
     </body>
@@ -230,7 +248,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  205 => 40,  198 => 39,  188 => 102,  186 => 99,  182 => 98,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  223 => 40,  216 => 39,  206 => 120,  204 => 117,  200 => 116,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
